==> ikaaro-0.50.5.tar.gz: ikaaro-0.50.5/ui/tiny_mce/plugins/media/langs/de_dlg.js <==
tinyMCE.addI18n('de.media_dlg',{
title:"Multimedia-Inhalte einf\u00FCgen / bearbeiten",
general:"Allgemein",
advanced:"Erweitert",
file:"Datei/URL",
list:"Liste",
size:"Abmessungen",
preview:"Vorschau",
constrain_proportions:"Proportionen erhalten",
type:"Typ",
id:"Id",
name:"Name",
class_name:"CSS-Klasse",
vspace:"Vertikaler Abstand",
hspace:"Horizontaler Abstand",
play:"Automatisches Abspielen",
loop:"Wiederholung",
menu:"Men\u00FC anzeigen",
quality:"Qualit\u00E4t",
scale:"Skalierung",
align:"Ausrichtung",
salign:"S-Ausrichtung",
wmode:"WMode",
bgcolor:"Hintergrund",
base:"Base",
flashvars:"Flashvariablen",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Zwischenspeicher",
hidden:"Versteckt",
controller:"Controller",
kioskmode:"Kioskmodus",
playeveryframe:"Jeden Frame abspielen",
targetcache:"Ziel zwischenspeichern",
correction:"Ohne Korrektur",
enablejavascript:"JavaScript aktivieren",
starttime:"Startzeitpunkt",
endtime:"Endzeitpunkt",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Ziel",
volume:"Lautst\u00E4rke",
autostart:"Autostart",
enabled:"Aktiviert",
fullscreen:"Vollbild",
invokeurls:"Invoke URLs",
mute:"Stumm",
stretchtofit:"Anzeigefl\u00E4che an verf\u00FCgbaren Platz anpassen",
windowlessvideo:"Fensterloses Video",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Aktueller Marker",
currentposition:"Aktuelle Position",
defaultframe:"Frame-Voreinstellung",
playcount:"Z\u00E4hler",
rate:"Rate",
uimode:"UI Modus",
flash_options:"Flash-Optionen",
qt_options:"Quicktime-Optionen",
wmp_options:"Optionen f\u00FCr Windows Media Player",
rmp_options:"Optionen f\u00FCr Real Media Player",
shockwave_options:"Shockwave-Optionen",
autogotourl:"Auto goto URL",
center:"Zentriert",
imagestatus:"Bildstatus",
maintainaspect:"Bildverh\u00E4ltnis beibehalten",
nojava:"Kein Java",
prefetch:"Prefetch",
shuffle:"Zuf\u00E4llige Wiedergabe",
console:"Konsole",
numloop:"Anzahl Wiederholungen",
controls:"Steuerung",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Ausrichtung",
swstretchvalign:"Stretch V-Ausrichtung",
sound:"Ton",
progress:"Fortschritt",
qtsrc:"QT Src",
qt_stream_warn:"In den Erweiterten Einstellungen sollten im Feld 'QT Src' gestreamte rtsp Resourcen hinzugef\u00FCgt werden.\nzus\u00E4tzlich sollten Sie dort auch eine nicht-gestreamte Resource angeben.",
align_top:"Oben",
align_right:"Rechts",
align_bottom:"Unten",
align_left:"Links",
align_center:"Zentriert",
align_top_left:"Oben Links",
align_top_right:"Oben Rechts",
align_bottom_left:"Unten Links",
align_bottom_right:"Unten Rechts",
flv_options:"Optionen f\u00FCr Flash Video",
flv_scalemode:"Skalierungsmodus",
flv_buffer:"Puffer",
flv_startimage:"Startbild",
flv_starttime:"Startzeitpunkt",
flv_defaultvolume:"Standardlautst\u00E4rke",
flv_hiddengui:"Versteckte GUI",
flv_autostart:"Autostart",
flv_loop:"Wiederholung",
flv_showscalemodes:"Skalierungsmodi anzeigen",
flv_smoothvideo:"Smooth Video",
flv_jscallback:"JS Callback"
});

==> ikaaro-0.61.4.tar.gz: ikaaro-0.61.4/ui/tiny_mce/plugins/media/langs/de_dlg.js <==
tinyMCE.addI18n('de.media_dlg',{
title:"Multimedia-Inhalte einf\u00FCgen/bearbeiten",
general:"Allgemein",
advanced:"Erweitert",
file:"Datei/URL",
list:"Liste",
size:"Abmessungen",
preview:"Vorschau",
constrain_proportions:"Proportionen erhalten",
type:"Typ",
id:"Id",
name:"Name",
class_name:"CSS-Klasse",
vspace:"Vertikaler Abstand",
hspace:"Horizontaler Abstand",
play:"Automatisches Abspielen",
loop:"Wiederholung",
menu:"Men\u00FC anzeigen",
quality:"Qualit\u00E4t",
scale:"Skalierung",
align:"Ausrichtung",
salign:"S-Ausrichtung",
wmode:"WMode",
bgcolor:"Hintergrund",
base:"Base",
flashvars:"Flashvariablen",
liveconnect:"SWLiveConnect",
autohref:"AutoHREF",
cache:"Zwischenspeicher",
hidden:"Versteckt",
controller:"Controller",
kioskmode:"Kioskmodus",
playeveryframe:"Jeden Frame abspielen",
targetcache:"Ziel zwischenspeichern",
correction:"Ohne Korrektur",
enablejavascript:"JavaScript aktivieren",
starttime:"Startzeitpunkt",
endtime:"Endzeitpunkt",
href:"Href",
qtsrcchokespeed:"Choke speed",
target:"Ziel",
volume:"Lautst\u00E4rke",
autostart:"Autostart",
enabled:"Aktiviert",
fullscreen:"Vollbild",
invokeurls:"Invoke URLs",
mute:"Stumm",
stretchtofit:"Anzeigefl\u00E4che an verf\u00FCgbaren Platz anpassen",
windowlessvideo:"Fensterloses Video",
balance:"Balance",
baseurl:"Base URL",
captioningid:"Captioning id",
currentmarker:"Aktueller Marker",
currentposition:"Aktuelle Position",
defaultframe:"Frame-Voreinstellung",
playcount:"Z\u00E4hler",
rate:"Rate",
uimode:"UI Modus",
flash_options:"Flash-Optionen",
qt_options:"Quicktime-Optionen",
wmp_options:"Optionen f\u00FCr Windows Media Player",
rmp_options:"Optionen f\u00FCr Real Media Player",
shockwave_options:"Shockwave-Optionen",
autogotourl:"Auto goto URL",
center:"Zentriert",
imagestatus:"Bildstatus",
maintainaspect:"Bildverh\u00E4ltnis beibehalten",
nojava:"Kein Java",
prefetch:"Prefetch",
shuffle:"Zuf\u00E4llige Wiedergabe",
console:"Konsole",
numloop:"Anzahl Wiederholungen",
controls:"Steuerung",
scriptcallbacks:"Script callbacks",
swstretchstyle:"Stretch style",
swstretchhalign:"Stretch H-Ausrichtung",
swstretchvalign:"Stretch V-Ausrichtung",
sound:"Ton",
progress:"Fortschritt",
qtsrc:"QT Src",
qt_stream_warn:"In den Erweiterten Einstellungen sollten im Feld 'QT Src' gestreamte RTSP Resourcen hinzugef\u00FCgt werden.\nZus\u00E4tzlich sollten Sie dort auch eine nicht-gestreamte Resource angeben.",
align_top:"Oben",
align_right:"Rechts",
align_bottom:"Unten",
align_left:"Links",
align_center:"Zentriert",
align_top_left:"Oben Links",
align_top_right:"Oben Rechts",
align_bottom_left:"Unten Links",
align_bottom_right:"Unten Rechts",
flv_options:"Optionen f\u00FCr Flash Video",
flv_scalemode:"Skalierungsmodus",
flv_buffer:"Puffer",
flv_startimage:"Startbild",
flv_starttime:"Startzeitpunkt",
flv_defaultvolume:"Standardlautst\u00E4rke",
flv_hiddengui:"Versteckte GUI",
flv_autostart:"Autostart",
flv_loop:"Wiederholung",
flv_showscalemodes:"Skalierungsmodi anzeigen",
flv_smoothvideo:"Smooth Video",
flv_jscallback:"JS Callback"
});
